"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const radash_1 = __importDefault(require("radash"));
const aws = __importStar(require("@pulumi/aws"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const pulumi_aws_lambda_api_1 = require("@exobase/pulumi-aws-lambda-api");
const main = async () => {
    //
    //  READ PROJECT CONFIG
    //
    const context = await fs_extra_1.default.readJSON('./context.json');
    const { platform, service, deployment } = context;
    const config = deployment.config.stack;
    //
    //  SETUP PROVIDER
    //
    const provider = new aws.Provider('aws', {
        secretKey: platform.providers.aws.accessKeySecret,
        accessKey: platform.providers.aws.accessKeyId,
        region: platform.providers.aws.region
    });
    //
    //  CREATE API/LAMBDA RESOURCES
    //
    const envVarDict = deployment.config.environmentVariables.reduce((acc, ev) => ({
        ...acc,
        [ev.name]: ev.value
    }), {});
    const api = new pulumi_aws_lambda_api_1.AWSLambdaAPI('api', {
        sourceDir: `${__dirname}/source`,
        sourceExt: 'ts',
        distDirName: 'build',
        buildCommand: (() => {
            const useNvm = !!process.env.USE_NVM;
            const nvmPrefix = 'source ~/.nvm/nvm.sh && nvm use && ';
            const cmd = 'yarn && yarn build && cp package.json ./build/package.json && cd build && yarn';
            return `${useNvm ? nvmPrefix : ''}${cmd}`;
        })(),
        runtime: 'nodejs14.x',
        timeout: toNumber(config.timeout),
        memory: toNumber(config.memory),
        environmentVariables: {
            ...envVarDict,
            EXOBASE_PLATFORM: platform.name,
            EXOBASE_SERVICE: service.name
        },
        domain: service.domain
    }, { provider });
    return {
        url: service.domain ? service.domain.fqd : api.api.url
    };
};
const toNumber = (value) => {
    if (radash_1.default.isString)
        return parseInt(value);
    return value;
};
exports.default = main;
